@@ -15,6 +15,7 @@ library("gamlss")
 library("testthat")
 library("ggplot2")
 library("gridExtra")
+library("betareg")
 
 ## Delete everything
 rm(list = ls())
@@ -55,6 +56,11 @@ test_core <- function(fam_name) {
                     data = art_data, family = fam_name, trace = FALSE)
   }
 
+  if (distreg.vis:::is.betareg(fam_name)) {
+    model <- betareg(betareg ~ norm2 + binomial1 | norm2 + binomial1,
+                     data = art_data)
+  }
+
   ########   ---    plot_dist()   ---    ########
 
   ## Predict parameters and plot distribution
@@ -93,12 +99,20 @@ test_core <- function(fam_name) {
 
     # Not specifying an external function
     if (!fam_name %in% c("LOGNO", "gamma")) {
+      # With pred_data
       plots_moments <- arrangeGrob(
         plot_moments(model, "norm2", pred_data = ndata),
         plot_moments(model, "binomial1", pred_data = ndata),
         ncol = 2,
         nrow = 1
       )
+      # Without pred_data
+      plots_moments_free <- arrangeGrob(
+        plot_moments(model, "norm2"),
+        plot_moments(model, "binomial1"),
+        ncol = 2,
+        nrow = 1
+      )
     }
 
     # Specifying an external function
@@ -106,16 +120,25 @@ test_core <- function(fam_name) {
       ineq <<- function(par) {
         2 * pnorm((par[["sigma"]] / 2) * sqrt(2)) - 1
       }
+      # With pred_data
       plots_moments <- arrangeGrob(
         plot_moments(model, "norm2", pred_data = ndata, ex_fun = "ineq"),
         plot_moments(model, "binomial1", pred_data = ndata, ex_fun = "ineq"),
         ncol = 2,
         nrow = 1
       )
+      # Without pred_data
+      plots_moments_free <- arrangeGrob(
+        plot_moments(model, "norm2", ex_fun = "ineq"),
+        plot_moments(model, "binomial1", ex_fun = "ineq"),
+        ncol = 2,
+        nrow = 1
+      )
     }
 
     # Obtaining samples and uncertainty (only one dist because otherwise test would be too long)
     if (fam_name == "gamma") {
+      # With specifying pred_data
       plots_moments <- arrangeGrob(
         plot_moments(model, "norm2", pred_data = ndata,
                      samples = TRUE, uncertainty = TRUE),
@@ -124,14 +147,11 @@ test_core <- function(fam_name) {
         ncol = 2,
         nrow = 1
       )
-    }
-
-    # BAMLSS (with samples)
-    if (distreg.vis:::is.bamlss(fam_name)) {
-      plots_moments <- arrangeGrob(
-        plot_moments(model, "norm2", pred_data = ndata,
+      # Without specifying pred_data
+      plots_moments_free <- arrangeGrob(
+        plot_moments(model, "norm2",
                      samples = TRUE, uncertainty = TRUE),
-        plot_moments(model, "binomial1", pred_data = ndata,
+        plot_moments(model, "binomial1",
                      samples = TRUE, uncertainty = TRUE),
         ncol = 2,
         nrow = 1
@@ -141,7 +161,11 @@ test_core <- function(fam_name) {
     # Save
     fileloc <- tempfile(pattern = paste0("plot_", fam_name, "_moments"),
                         fileext = ".png")
-    ggsave(filename = fileloc, height = 12, width = 24, plot = plots_moments,
+    fileloc_free <- tempfile(pattern = paste0("plot_", fam_name, "_moments_free"),
+                             fileext = ".png")
+    ggsave(filename = fileloc, height = 7, width = 14, plot = plots_moments,
+           units = "cm", device = "png")
+    ggsave(filename = fileloc_free, height = 7, width = 14, plot = plots_moments_free,
            units = "cm", device = "png")
   } else {
     expect_error(plot_moments(model, "norm2", pred_data = ndata))
